==> hinemos_agent-4.0.1_rhel5_32.tar.gz: com/clustercontrol/ws/monitor/MonitorStringValueInfo.java <==

package com.clustercontrol.ws.monitor;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for monitorStringValueInfo complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="monitorStringValueInfo">
 *   &lt;complexContent>
 *     &lt;extension base="{http://monitor.ws.clustercontrol.com}monitorJudgementInfo">
 *       &lt;sequence>
 *         &lt;element name="caseSensitivityFlg" type="{http://www.w3.org/2001/XMLSchema}boolean"/>
 *         &lt;element name="description" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="identifier" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="orderNo" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="pattern" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="processType" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="validFlg" type="{http://www.w3.org/2001/XMLSchema}boolean"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "monitorStringValueInfo", propOrder = {
    "caseSensitivityFlg",
    "description",
    "identifier",
    "orderNo",
    "pattern",
    "processType",
    "validFlg"
})
public class MonitorStringValueInfo
    extends MonitorJudgementInfo
{

    protected boolean caseSensitivityFlg;
    protected String description;
    protected String identifier;
    protected int orderNo;
    protected String pattern;
    protected int processType;
    protected boolean validFlg;

    /**
     * Gets the value of the caseSensitivityFlg property.
     * 
     */
    public boolean isCaseSensitivityFlg() {
        return caseSensitivityFlg;
    }

    /**
     * Sets the value of the caseSensitivityFlg property.
     * 
     */
    public void setCaseSensitivityFlg(boolean value) {
        this.caseSensitivityFlg = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDescription() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDescription(String value) {
        this.description = value;
    }

    /**
     * Gets the value of the identifier property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIdentifier() {
        return identifier;
    }

    /**
     * Sets the value of the identifier property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIdentifier(String value) {
        this.identifier = value;
    }

    /**
     * Gets the value of the orderNo property.
     * 
     */
    public int getOrderNo() {
        return orderNo;
    }

    /**
     * Sets the value of the orderNo property.
     * 
     */
    public void setOrderNo(int value) {
        this.orderNo = value;
    }

    /**
     * Gets the value of the pattern property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPattern() {
        return pattern;
    }

    /**
     * Sets the value of the pattern property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPattern(String value) {
        this.pattern = value;
    }

    /**
     * Gets the value of the processType property.
     * 
     */
    public int getProcessType() {
        return processType;
    }

    /**
     * Sets the value of the processType property.
     * 
     */
    public void setProcessType(int value) {
        this.processType = value;
    }

    /**
     * Gets the value of the validFlg property.
     * 
     */
    public boolean isValidFlg() {
        return validFlg;
    }

    /**
     * Sets the value of the validFlg property.
     * 
     */
    public void setValidFlg(boolean value) {
        this.validFlg = value;
    }

}

==> hinemos_agent-4.1.4_rhel5-7.tar.gz: com/clustercontrol/ws/monitor/MonitorStringValueInfo.java <==

package com.clustercontrol.ws.monitor;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>monitorStringValueInfo complex typeのJavaクラス。
 * 
 * <p>次のスキーマ・フラグメントは、このクラス内に含まれる予期されるコンテンツを指定します。
 * 
 * <pre>
 * &lt;complexType name="monitorStringValueInfo">
 *   &lt;complexContent>
 *     &lt;extension base="{http://monitor.ws.clustercontrol.com}monitorJudgementInfo">
 *       &lt;sequence>
 *         &lt;element name="caseSensitivityFlg" type="{http://www.w3.org/2001/XMLSchema}boolean"/>
 *         &lt;element name="description" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="identifier" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="orderNo" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="pattern" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="processType" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="validFlg" type="{http://www.w3.org/2001/XMLSchema}boolean"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "monitorStringValueInfo", propOrder = {
    "caseSensitivityFlg",
    "description",
    "identifier",
    "orderNo",
    "pattern",
    "processType",
    "validFlg"
})
public class MonitorStringValueInfo
    extends MonitorJudgementInfo
{

    protected boolean caseSensitivityFlg;
    protected String description;
    protected String identifier;
    protected int orderNo;
    protected String pattern;
    protected int processType;
    protected boolean validFlg;

    /**
     * caseSensitivityFlgプロパティの値を取得します。
     * 
     */
    public boolean isCaseSensitivityFlg() {
        return caseSensitivityFlg;
    }

    /**
     * caseSensitivityFlgプロパティの値を設定します。
     * 
     */
    public void setCaseSensitivityFlg(boolean value) {
        this.caseSensitivityFlg = value;
    }

    /**
     * descriptionプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDescription() {
        return description;
    }

    /**
     * descriptionプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDescription(String value) {
        this.description = value;
    }

    /**
     * identifierプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIdentifier() {
        return identifier;
    }

    /**
     * identifierプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIdentifier(String value) {
        this.identifier = value;
    }

    /**
     * orderNoプロパティの値を取得します。
     * 
     */
    public int getOrderNo() {
        return orderNo;
    }

    /**
     * orderNoプロパティの値を設定します。
     * 
     */
    public void setOrderNo(int value) {
        this.orderNo = value;
    }

    /**
     * patternプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPattern() {
        return pattern;
    }

    /**
     * patternプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPattern(String value) {
        this.pattern = value;
    }

    /**
     * processTypeプロパティの値を取得します。
     * 
     */
    public int getProcessType() {
        return processType;
    }

    /**
     * processTypeプロパティの値を設定します。
     * 
     */
    public void setProcessType(int value) {
        this.processType = value;
    }

    /**
     * validFlgプロパティの値を取得します。
     * 
     */
    public boolean isValidFlg() {
        return validFlg;
    }

    /**
     * validFlgプロパティの値を設定します。
     * 
     */
    public void setValidFlg(boolean value) {
        this.validFlg = value;
    }

}
